#-*- coding: utf-8 -*-

from setuptools import setup, find_packages

setup(
    name="MouseSim",
    version="1.0.0",
    description="It is a simple and flexible simulation library in Python that performs human-like mouse movements.",
    long_description=open("README.md", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    author="Kemal Sayıt",
    author_email="kemalsayit01@gmail.com",
    url="https://github.com/Leo4Bey/MouseSim",
    packages=find_packages(),
    py_modules=["MouseSim"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: Microsoft :: Windows",
    ],
    python_requires='>=3.7',
    install_requires=[],
    keywords = [
    "mouse movement",
    "human-like mouse",
    "mouse simulation",
    "mouse automation",
    "python mouse control",
    "randomized movement",
    "easing functions",
    "natural interaction",
    "ui automation",
    "desktop automation",
    "pyautogui",
    "automation tools",
    "mouse mover",
    "mouse path simulator",
    "anti bot detection",
    "bot evasion",
    "robot detection",
    "realistic mouse",
    "gui testing",
    "mouse click automation"
    ],
    project_urls={
        "Source": "https://github.com/Leo4Bey/MouseSim",
        "Bug Tracker": "https://github.com/Leo4Bey/MouseSim/issues",
    },
)